@@ -53,6 +53,8 @@ class Selenium(Scraper):
         options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36") # new
         # options.add_argument("user-data-dir=C:\\Users\\LCADM.G.Gargiuolo\\AppData\\Local\\Google\\Chrome\\User Data\\Default") # new
 
+        capabilities = {'browserName': 'chrome', 'javascriptEnabled': True}
+        capabilities.update(options.to_capabilities())
         self.driver = webdriver.Remote('http://selenium:4444/wd/hub', desired_capabilities=DesiredCapabilities.CHROME)
 
         # if platform.system() == 'Windows':
